@@ -6,3 +6,7 @@ from .whisper_model import PubSubWhisper
 from .subscription_model import PubSubSubscription
 from .pubsub_moderation_action import PubSubModerationAction
 from .subscription_model import PubSubSubscription
+from .bits_model import PubSubBits
+from .pubsub_poll_update import *
+from .twitch_poll_vote_choice import *
+from .pubsub_follow import *
